[ovs-dev] [of1.1 draft 01/10] nicira-ext: Rename "struct nxt_*" to "struct nx_*".

Ben Pfaff blp at nicira.com
Thu Dec 8 04:17:20 UTC 2011


Most structures in this file have an "nx_" prefix, so this makes naming
more consistent.
---
 include/openflow/nicira-ext.h |   10 +++++-----
 lib/ofp-print.c               |    4 ++--
 lib/ofp-util.c                |    8 ++++----
 ofproto/ofproto.c             |    8 ++++----
 4 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/lib/ofp-print.c b/lib/ofp-print.c
index fe852b4..67f5883 100644
--- a/lib/ofp-print.c
+++ b/lib/ofp-print.c
@@ -1259,14 +1259,14 @@ ofp_print_nxt_role_message(struct ds *string,
 
 static void
 ofp_print_nxt_flow_mod_table_id(struct ds *string,
-                                const struct nxt_flow_mod_table_id *nfmti)
+                                const struct nx_flow_mod_table_id *nfmti)
 {
     ds_put_format(string, " %s", nfmti->set ? "enable" : "disable");
 }
 
 static void
 ofp_print_nxt_set_flow_format(struct ds *string,
-                              const struct nxt_set_flow_format *nsff)
+                              const struct nx_set_flow_format *nsff)
 {
     uint32_t format = ntohl(nsff->format);
 
diff --git a/lib/ofp-util.c b/lib/ofp-util.c
index 11b0f15..b99eadc 100644
--- a/lib/ofp-util.c
+++ b/lib/ofp-util.c
@@ -361,7 +361,7 @@ ofputil_decode_vendor(const struct ofp_header *oh, size_t length,
 
         { OFPUTIL_NXT_SET_FLOW_FORMAT,
           NXT_SET_FLOW_FORMAT, "NXT_SET_FLOW_FORMAT",
-          sizeof(struct nxt_set_flow_format), 0 },
+          sizeof(struct nx_set_flow_format), 0 },
 
         { OFPUTIL_NXT_FLOW_MOD,
           NXT_FLOW_MOD, "NXT_FLOW_MOD",
@@ -373,7 +373,7 @@ ofputil_decode_vendor(const struct ofp_header *oh, size_t length,
 
         { OFPUTIL_NXT_FLOW_MOD_TABLE_ID,
           NXT_FLOW_MOD_TABLE_ID, "NXT_FLOW_MOD_TABLE_ID",
-          sizeof(struct nxt_flow_mod_table_id), 0 },
+          sizeof(struct nx_flow_mod_table_id), 0 },
     };
 
     static const struct ofputil_msg_category nxt_category = {
@@ -918,7 +918,7 @@ ofputil_min_flow_format(const struct cls_rule *rule)
 struct ofpbuf *
 ofputil_make_set_flow_format(enum nx_flow_format flow_format)
 {
-    struct nxt_set_flow_format *sff;
+    struct nx_set_flow_format *sff;
     struct ofpbuf *msg;
 
     sff = make_nxmsg(sizeof *sff, NXT_SET_FLOW_FORMAT, &msg);
@@ -932,7 +932,7 @@ ofputil_make_set_flow_format(enum nx_flow_format flow_format)
 struct ofpbuf *
 ofputil_make_flow_mod_table_id(bool flow_mod_table_id)
 {
-    struct nxt_flow_mod_table_id *nfmti;
+    struct nx_flow_mod_table_id *nfmti;
     struct ofpbuf *msg;
 
     nfmti = make_nxmsg(sizeof *nfmti, NXT_FLOW_MOD_TABLE_ID, &msg);
diff --git a/ofproto/ofproto.c b/ofproto/ofproto.c
index b81bd6b..810fe12 100644
--- a/ofproto/ofproto.c
+++ b/ofproto/ofproto.c
@@ -2808,8 +2808,8 @@ static int
 handle_nxt_flow_mod_table_id(struct ofconn *ofconn,
                              const struct ofp_header *oh)
 {
-    const struct nxt_flow_mod_table_id *msg
-        = (const struct nxt_flow_mod_table_id *) oh;
+    const struct nx_flow_mod_table_id *msg
+        = (const struct nx_flow_mod_table_id *) oh;
 
     ofconn_set_flow_mod_table_id(ofconn, msg->set != 0);
     return 0;
@@ -2818,8 +2818,8 @@ handle_nxt_flow_mod_table_id(struct ofconn *ofconn,
 static int
 handle_nxt_set_flow_format(struct ofconn *ofconn, const struct ofp_header *oh)
 {
-    const struct nxt_set_flow_format *msg
-        = (const struct nxt_set_flow_format *) oh;
+    const struct nx_set_flow_format *msg
+        = (const struct nx_set_flow_format *) oh;
     uint32_t format;
 
     format = ntohl(msg->format);
diff --git a/include/openflow/nicira-ext.h b/include/openflow/nicira-ext.h
index f449329..90505c5 100644
--- a/include/openflow/nicira-ext.h
+++ b/include/openflow/nicira-ext.h
@@ -161,7 +161,7 @@ enum nicira_type {
 
     /* Use the upper 8 bits of the 'command' member in struct ofp_flow_mod to
      * designate the table to which a flow is to be added?  See the big comment
      * on struct nxt_flow_mod_table_id for more information. */
     NXT_FLOW_MOD_TABLE_ID = 15
 };
 
@@ -237,14 +237,14 @@ enum nx_hash_fields {
  *      matches, then it is modified or deleted; if flows in more than one
  *      table match, then none is modified or deleted.
  */
-struct nxt_flow_mod_table_id {
+struct nx_flow_mod_table_id {
     struct ofp_header header;
     uint32_t vendor;            /* NX_VENDOR_ID. */
     uint32_t subtype;           /* NXT_FLOW_MOD_TABLE_ID. */
     uint8_t set;                /* Nonzero to enable, zero to disable. */
     uint8_t pad[7];
 };
-OFP_ASSERT(sizeof(struct nxt_flow_mod_table_id) == 24);
+OFP_ASSERT(sizeof(struct nx_flow_mod_table_id) == 24);
 
 /* Configures the "role" of the sending controller.  The default role is:
  *
@@ -1651,13 +1651,13 @@ enum nx_flow_format {
 };
 
 /* NXT_SET_FLOW_FORMAT request. */
-struct nxt_set_flow_format {
+struct nx_set_flow_format {
     struct ofp_header header;
     ovs_be32 vendor;            /* NX_VENDOR_ID. */
     ovs_be32 subtype;           /* NXT_SET_FLOW_FORMAT. */
     ovs_be32 format;            /* One of NXFF_*. */
 };
-OFP_ASSERT(sizeof(struct nxt_set_flow_format) == 20);
+OFP_ASSERT(sizeof(struct nx_set_flow_format) == 20);
 
 /* NXT_FLOW_MOD (analogous to OFPT_FLOW_MOD). */
 struct nx_flow_mod {
@@ -161,7 +161,7 @@ enum nicira_type {
     /* Use the upper 8 bits of the 'command' member in struct ofp_flow_mod to
      * designate the table to which a flow is to be added?  See the big comment
-     * on struct nxt_flow_mod_table_id for more information. */
+     * on struct nx_flow_mod_table_id for more information. */
     NXT_FLOW_MOD_TABLE_ID = 15
 };
-- 
1.7.2.5




More information about the dev mailing list